==> react-redux-grid-1.9.3.tgz: package/src/actions/plugins/selection/ModelActions.js <==
import {
    SET_SELECTION,
    SELECT_ALL,
    DESELECT_ALL,
    NO_EVENT
} from '../../../constants/ActionTypes';

import { keyGenerator } from '../../../util/keyGenerator';

export function selectAll({ data, stateKey }) {
    const keys = data.currentRecords.map((row, i) => keyGenerator('row', i));

    const selection = keys.reduce((obj, k) => {
        obj[k] = true;
        return obj;
    }, {});
    return { type: SELECT_ALL, selection, stateKey };
}

export function deselectAll({ stateKey }) {
    return { type: DESELECT_ALL, stateKey };
}

export function setSelection({
    id, defaults = {}, modes = {}, stateKey, index
}) {

    const allowDeselect = defaults.allowDeselect;
    const clearSelections = defaults.mode === modes.checkboxSingle
        || defaults.mode === modes.single;

    if (!defaults.enabled) {
        console.warn('Selection model has been disabled');
        return { type: NO_EVENT };
    }

    if (defaults.mode === modes.single) {
        return {
            type: SET_SELECTION,
            id,
            clearSelections,
            allowDeselect,
            index,
            stateKey
        };
    }

    else if (defaults.mode === modes.multi) {
        return { type: SET_SELECTION, id, allowDeselect, index, stateKey };
    }

    else if (defaults.mode === modes.checkboxSingle
        || defaults.mode === modes.checkboxMulti) {
        return {
            type: SET_SELECTION,
            id,
            clearSelections,
            allowDeselect,
            index,
            stateKey
        };
    }
}

==> react-redux-grid-4.3.1.tgz: package/src/actions/plugins/selection/ModelActions.js <==
import {
    SET_SELECTION,
    SELECT_ALL,
    DESELECT_ALL,
    NO_EVENT,
    SELECT_ROW,
    DESELECT_ROW
} from '../../../constants/ActionTypes';

export const selectRow = ({ stateKey, rowId }) => ({
    type: SELECT_ROW,
    stateKey,
    rowId
});

export const deselectRow = ({ stateKey, rowId }) => ({
    type: DESELECT_ROW,
    stateKey,
    rowId
});

export const selectAll = ({ data, stateKey }) => {

    if (!data) {
        return {};
    }

    const keys = data.currentRecords.map((row) => row._key);

    const selection = keys.reduce((obj, k) => {
        obj[k] = true;
        return obj;
    }, {});

    return { type: SELECT_ALL, selection, stateKey };
};

export const deselectAll = ({ stateKey }) => ({
    type: DESELECT_ALL, stateKey
});

export const setSelection = ({
    id, defaults = {}, modes = {}, stateKey, index
}) => {

    const allowDeselect = defaults.allowDeselect;
    const clearSelections = defaults.mode === modes.checkboxSingle
        || defaults.mode === modes.single;

    if (!defaults.enabled) {
        /* eslint-disable no-console */
        console.warn('Selection model has been disabled');
        /* eslint-enable no-console */
        return { type: NO_EVENT };
    }

    if (defaults.mode === modes.single) {
        return {
            type: SET_SELECTION,
            id,
            clearSelections,
            allowDeselect,
            index,
            stateKey
        };
    }

    else if (defaults.mode === modes.multi) {
        return { type: SET_SELECTION, id, allowDeselect, index, stateKey };
    }

    else if (defaults.mode === modes.checkboxSingle
        || defaults.mode === modes.checkboxMulti) {
        return {
            type: SET_SELECTION,
            id,
            clearSelections,
            allowDeselect,
            index,
            stateKey
        };
    }
};
